import os
from datasets import load_dataset,DatasetDict
from transformers import AutoTokenizer
from transformers import LlamaTokenizerFast

def calc_tokens(hf_dataset, token_path:str,epoch:int):
    try:
        tokenizer = AutoTokenizer.from_pretrained(token_path, trust_remote_code=True)
    except Exception as e:
        tokenizer = LlamaTokenizerFast.from_pretrained(token_path)

    def count_tokens(example):
        len_token_cnts = []
        for instruction,input,output in zip(example['instruction'],example['input'],example['output']):
            full_prompt = instruction + input + output
            token_cnt = tokenizer.tokenize(full_prompt)
            len_token_cnt = len(token_cnt)
            len_token_cnts.append(len_token_cnt)
        return {'total_tokens':len_token_cnts}
    
    token_dict = hf_dataset.map(count_tokens,
                                remove_columns=['instruction', 'input', 'output'],
                                batched=True)

    col_token = token_dict['train']['total_tokens'] if isinstance(hf_dataset, DatasetDict) else token_dict['total_tokens'] 
    print(f'sum col_tolens {sum(col_token)}')
    return sum(col_token)